@@ -87,10 +87,8 @@ baobab_set_busy (gboolean busy)
 		gedit_spinner_start (GEDIT_SPINNER (baobab.spinner));
 
 		baobab_chart_freeze_updates (baobab.rings_chart);
-		baobab_chart_set_summary_mode (baobab.rings_chart, FALSE);
 
 		baobab_chart_freeze_updates (baobab.treemap_chart);
-		baobab_chart_set_summary_mode (baobab.treemap_chart, FALSE);
 
 		gtk_widget_set_sensitive (baobab.chart_type_combo, FALSE);
 	}
@@ -325,8 +323,27 @@ first_row (void)
 	gdouble perc;
 	char *label;
 
+        GtkTreeIter root_iter;
+
+	gchar *capacity_label, *capacity_size;
+
+	gtk_tree_store_append (baobab.model, &root_iter, NULL);
+	capacity_size = g_format_size_for_display (g_fs.total);
+
+	capacity_label = g_strdup (_("Total filesystem capacity"));
+	gtk_tree_store_set (baobab.model, &root_iter,
+			    COL_DIR_NAME, capacity_label,
+			    COL_H_PARSENAME, "",
+			    COL_H_PERC, 100.0,
+			    COL_DIR_SIZE, capacity_size,
+			    COL_H_SIZE, g_fs.total,
+			    COL_H_ALLOCSIZE, g_fs.total,
+			    COL_H_ELEMENTS, -1, -1);
+	g_free (capacity_label);
+	g_free (capacity_size);
+
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (baobab.tree_view), FALSE);
-	gtk_tree_store_append (baobab.model, &firstiter, NULL);
+	gtk_tree_store_append (baobab.model, &firstiter, &root_iter);
 	size = g_format_size_for_display (g_fs.used);
 	if (g_fs.total == 0 && g_fs.used == 0) {
 		perc = 100.0;
@@ -335,7 +352,7 @@ first_row (void)
 		perc = ((gdouble) g_fs.used * 100) / (gdouble) g_fs.total;
 	}
 
-	label = g_strdup_printf ("<i>%s</i>", _("Total filesystem usage:"));
+	label = g_strdup (_("Total filesystem usage"));
 	gtk_tree_store_set (baobab.model, &firstiter,
 			    COL_DIR_NAME, label,
 			    COL_H_PARSENAME, "",
@@ -347,6 +364,8 @@ first_row (void)
 
 	g_free (size);
 	g_free (label);
+
+	gtk_tree_view_expand_all (GTK_TREE_VIEW (baobab.tree_view));
 }
 
 /* fills model during scanning */
@@ -981,9 +1000,26 @@ start_proc_on_command_line (GFile *file)
 	return FALSE;
 }
 
+static gboolean
+show_version (const gchar *option_name,
+              const gchar *value,
+              gpointer data,
+              GError **error)
+{
+	g_print("%s %s\n", g_get_application_name (), VERSION);
+	exit (0);
+	return TRUE; /* It's just good form */
+}
+
 int
 main (int argc, char *argv[])
 {
+	gchar **directories = NULL;
+	const GOptionEntry options[] = {
+		{"version", 'V', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, show_version, N_("Show version"), NULL},
+		{G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &directories, NULL, N_("[DIRECTORY]")},
+		{NULL}
+	};
 	GOptionContext *context;
 	GError *error = NULL;
 
@@ -991,9 +1027,12 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	g_set_application_name ("Baobab");
+
 	context = g_option_context_new (NULL);
 	g_option_context_set_ignore_unknown_options (context, FALSE);
 	g_option_context_set_help_enabled (context, TRUE);
+	g_option_context_add_main_entries(context, options, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
 	g_option_context_parse (context, &argc, &argv, &error);
@@ -1007,7 +1046,10 @@ main (int argc, char *argv[])
 	}
 	g_option_context_free (context);
 
-	g_set_application_name ("Baobab");
+	if (directories && directories[0] && directories[1]) {
+		g_critical (_("Too many arguments. Only one directory can be specified."));
+		exit (1);
+	}
 
 	glibtop_init ();
 
@@ -1057,10 +1099,10 @@ main (int argc, char *argv[])
 	initialize_ringschart ();
 
 	/* commandline */
-	if (argc > 1) {
+	if (directories && directories[0]) {
 		GFile *file;
 
-		file = g_file_new_for_commandline_arg (argv[1]);
+		file = g_file_new_for_commandline_arg (directories[0]);
 
 		/* start processing the dir specified on the
 		 * command line as soon as we enter the main loop */
@@ -1069,6 +1111,7 @@ main (int argc, char *argv[])
 		                 file,
 		                 (GDestroyNotify) g_object_unref);
 	}
+	g_strfreev (directories);
 
 	gtk_main ();
 
